#
# spec file for package libexttextcat
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%define libname libexttextcat-2_0-0
Name:           libexttextcat
Version:        3.4.7
Release:        2.4
Summary:        Text categorization library datafiles and documents
License:        BSD-4-Clause
Group:          Productivity/Text/Convertors
URL:            https://wiki.documentfoundation.org/Libexttextcat
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
Obsoletes:      libtextcat < 3.2.0
Provides:       libtextcat = %{version}

%description
The %{name} is a library implementing N-gram-based text categorization

%package -n %{libname}
Summary:        Text categorization library
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libname}
The %{name} is a library implementing N-gram-based text categorization

%package devel
Summary:        Files for Developing with %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Obsoletes:      libtextcat-devel < 3.2.0
Provides:       libtextcat-devel = %{version}

%description devel
The %{name} is a library implementing N-gram-based text categorization

This package contains the libexttextcat development files.

%package tools
Summary:        Tool for creating custom document fingerprints
Group:          Productivity/Text/Convertors

%description tools
The %{name}-tools package contains the createfp program that allows
you to easily create your own document fingerprints.

%prep
%autosetup -p1
autoreconf -fiv

%build
%configure \
	--disable-static \
	--disable-werror \
	--docdir=%{_docdir}/%{name}
%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

%check
%make_build check

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%license LICENSE
%doc README*
%{_datadir}/%{name}*

%files -n %{libname}
%license LICENSE
%{_libdir}/*.so.0*

%files devel
%license LICENSE
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}*.pc
%{_includedir}/%{name}*
%{_datadir}/vala/vapi/%{name}.vapi

%files tools
%license LICENSE
%{_bindir}/*

%changelog
* Thu Feb 29 2024 Fridrich Strba <fstrba@suse.com>
- Don't use ldconfig_scriptlets macro missing on sle12
* Sun Jan 28 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 3.4.7:
  * Add Ilocano, Saraiki
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 3.4.6:
  * Add Venetian, Comorian, Maore, Sundanese, Quechua, South Bolivian,
    Papiamentu, Nganasan, Minangkabau, Ladin, Ligurian, Komi, Kabardian, Fon
    Finnish, Kven, Dzongkha, Chuvash, Bushi
* Wed Jan 24 2018 avindra@opensuse.org
- Version bump to 3.4.5
  * fixed broken uk.lm langclass
  * Fix -fsanitize=shift-base errors
- use new URL
- cleanup with spec-cleaner
* Tue Jul  8 2014 tchvatal@suse.com
- Version bump to 3.4.4:
  * Fix overlaping memcpy
* Sat Jan 25 2014 tchvatal@suse.com
- Version bump to 3.4.3:
  * bump release
    + overlapping memcpy
    + allow old spelling of TEXTCAT_RESULT_UNKOWN.
  * merge in Giulio's work and bump release
    + Updated libexttextcat.vapi.
    + Enable changing mindocsize at runtime.
    + Fixed spelling of TEXTCAT_RESULT_UNKOWN.
* Thu Dec 27 2012 cfarrell@suse.com
- license update: BSD-4-Clause
  BSD is not acceptable (not SPDX format). BSD-4-Clause is the better
  choice because of e.g. src/fingerprint.c
* Wed Nov  7 2012 tchvatal@suse.com
- Require data of the same version of the package.
* Tue Nov  6 2012 tchvatal@suse.com
- Use variables instead of hard declarations.
* Tue Nov  6 2012 tchvatal@suse.com
- Add vala dirs to the list so it builds.
* Tue Nov  6 2012 tchvatal@suse.com
- License is BSD.
* Tue Nov  6 2012 tchvatal@suse.com
- Homepage fix.
* Tue Nov  6 2012 tchvatal@suse.com
- Remove copy&pasto requires.
* Tue Nov  6 2012 tchvatal@suse.com
- Remove pointless file.
* Tue Nov  6 2012 tchvatal@suse.com
- Initial commit of 3.4.0 release.
